summaryrefslogtreecommitdiffstats
path: root/konsolekalendar/konsolekalendarepoch.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:53:50 +0000
commit7be55ffa061c026e35e2d6a0effe1161ddb0d41f (patch)
tree8474f9b444b2756228600050f07a7ff25de532b2 /konsolekalendar/konsolekalendarepoch.h
parentf587f20a6d09f1729dd0a8c1cd8ee0110aec7451 (diff)
downloadtdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.tar.gz
tdepim-7be55ffa061c026e35e2d6a0effe1161ddb0d41f.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1157655 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'konsolekalendar/konsolekalendarepoch.h')
-rw-r--r--konsolekalendar/konsolekalendarepoch.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/konsolekalendar/konsolekalendarepoch.h b/konsolekalendar/konsolekalendarepoch.h
index e6db6d77e..fedd392c3 100644
--- a/konsolekalendar/konsolekalendarepoch.h
+++ b/konsolekalendar/konsolekalendarepoch.h
@@ -28,7 +28,7 @@
#ifndef _KONSOLEKALENDAREPOCH_H_
#define _KONSOLEKALENDAREPOCH_H_
-#include <qdatetime.h>
+#include <tqdatetime.h>
/**
* @file konsolekalendarepoch.h
@@ -54,16 +54,16 @@ namespace KCal
~KonsoleKalendarEpoch();
/**
* Converts epoch time to QDateTime format.
* @param epoch epoch time.
*/
- static QDateTime epoch2QDateTime( uint epoch );
+ static TQDateTime epoch2TQDateTime( uint epoch );
/**
* Converts QT DateTime to epoch format.
* @param dt is a QDateTime to convert to an epoch.
*/
- static uint QDateTime2epoch( QDateTime dt );
+ static uint QDateTime2epoch( TQDateTime dt );
};
@@ -54,16 +54,16 @@ namespace KCal
~KonsoleKalendarEpoch();
/**
- * Converts epoch time to QDateTime format.
+ * Converts epoch time to TQDateTime format.
* @param epoch epoch time.
*/
@@ -54,16 +54,16 @@ namespace KCal
/**
* Converts QT DateTime to epoch format.
- * @param dt is a QDateTime to convert to an epoch.
+ * @param dt is a TQDateTime to convert to an epoch.
*/